import * as React from "react";
import { css, kfrm, styled } from "@elliemae/ds-system";
import { DSTruncatedTooltipText } from "@elliemae/ds-truncated-tooltip-text";
import { DSIndeterminateProgressIndicatorName, DSIndeterminateProgressIndicatorSlots } from "./constants/index.js";
const IndeterminateAnimation = (color) => kfrm`
  0% {
    transform: scaleX(0.015);
    transform-origin: 0% 0%;
    background-image: linear-gradient(to right, rgba(255,255,255,0.8) 10%, ${color});
  }
  25% {
    transform: scaleX(0.4);
  }
  50% {
    transform: scaleX(0.015);
    transform-origin: 100% 0%;
    background-image: linear-gradient(to right, rgba(255,255,255,0.8) 10%, ${color});
  }
  50.1% {
    transform: scaleX(0.015);
    transform-origin: 100% 0%;
    background-image: linear-gradient(to left, rgba(255,255,255,0.8) 10%, ${color});
  }
  75% {
    transform: scaleX(0.4);
  }
  100% {
    transform: scaleX(0.015);
    transform-origin: 0% 0%;
    background-image: linear-gradient(to left, rgba(255,255,255,0.8) 10%, ${color});
  }
`;
const ProcessingSuccess = kfrm`
  0%, 30% { transform: translateX(-50%); width: 50% }
  15%     { transform: translateX(150%); width: 50% }
  0%, 60% { transform: translateX(-50%); width: 50% }
  45%     { transform: translateX(150%); width: 50% }
  0%, 90% { transform: translateX(-50%); width: 50% }
  75%     { transform: translateX(150%); width: 50% }
  100%    { transform: translateX(0%); }
`;
const ProcessingSuccessEnd = (color) => kfrm`
  0%      { transform: translateX(-50%); width: 50% }
  45%     { transform: translateX(150%); width: 50% }
  100%    { transform: translateX(0%); background-color: ${color}; }
`;
const ProcessingFail = kfrm`
  0%, 30% { transform: translateX(-50%); width: 50% }
  15%     { transform: translateX(150%); width: 50% }
  0%, 60% { transform: translateX(-50%); width: 50% }
  45%     { transform: translateX(150%); width: 50% }
  0%, 90% { transform: translateX(-50%); width: 50% }
  75%     { transform: translateX(150%); width: 50%; }
  100%    { transform: translateX(0%); }
`;
const ProcessingFailEnd = kfrm`
  0%      { transform: translateX(-50%); width: 50% }
  45%     { transform: translateX(150%); width: 50% }
  100%    { transform: translateX(0%); background-color: #e34256; }
`;
const Container = styled("div", {
  name: DSIndeterminateProgressIndicatorName,
  slot: DSIndeterminateProgressIndicatorSlots.ROOT
})`
  width: 100%;
  padding: ${({ theme, lineOnly }) => lineOnly ? 0 : `${theme.space.xxs} ${theme.space.xs}`};
`;
const StyledTruncatedTooltipText = styled(DSTruncatedTooltipText, {
  name: DSIndeterminateProgressIndicatorName,
  slot: DSIndeterminateProgressIndicatorSlots.LABEL
})``;
const Bar = styled("div", {
  name: DSIndeterminateProgressIndicatorName,
  slot: DSIndeterminateProgressIndicatorSlots.BAR
})`
  background-color: ${({ theme }) => theme.colors.neutral[100]};
  overflow: hidden;
`;
const BarIndicator = styled("div", {
  name: DSIndeterminateProgressIndicatorName,
  slot: DSIndeterminateProgressIndicatorSlots.BAR_INDICATOR
})`
  height: ${({ theme }) => theme.space.xxxs};
  width: ${({ complete, failed, animated, processing, percent }) => `${!complete && !failed && !animated && processing ? percent : 100}%`};
  ${({ theme, complete, failed, processing, animated, processingComplete, processingFail }) => {
  if (!complete && !failed && !processing && !processingComplete && !processingFail)
    return css`
        background-color: ${theme.colors.neutral[500]};
      `;
  else if (complete && processing)
    return css`
        width: 100%;
        background-color: ${theme.colors.brand[500]};
        animation: ${ProcessingSuccessEnd(theme.colors.success[900])} 1s ease-in-out;
        animation-fill-mode: forwards;
      `;
  else if (complete && !processingComplete && !processing)
    return css`
        background-color: ${theme.colors.success[900]};
      `;
  else if (failed && !processingFail && !processing)
    return css`
        background-color: #e34256;
      `;
  else if (processing) {
    if (animated) {
      return css`
          width: 100%;
          animation: ${IndeterminateAnimation(theme.colors.brand[500])} 2s cubic-bezier(0.645, 0.045, 0.355, 1) infinite;
          background-color: ${theme.colors.brand[500]};
        `;
    }
    return css`
        background-color: ${theme.colors.brand[500]};
      `;
  } else if (processingComplete && !complete) {
    return css`
        width: 50%;
        animation: ${ProcessingSuccess} 4s infinite;
        animation-fill-mode: forwards;
        background-color: ${theme.colors.brand[500]};
      `;
  } else if (processingComplete && complete)
    return css`
        width: 100%;
        background-color: ${theme.colors.brand[500]};
        animation: ${ProcessingSuccessEnd(theme.colors.success[900])} 1s ease-in-out;
        animation-fill-mode: forwards;
      `;
  else if (processingFail && !failed)
    return css`
        width: 50%;
        animation: ${ProcessingFail} 4s infinite;
        animation-fill-mode: forwards;
        background-color: ${theme.colors.brand[500]};
      `;
  else if (processingFail && failed)
    return css`
        width: 100%;
        background-color: ${theme.colors.brand[500]};
        animation: ${ProcessingFailEnd} 1s ease-in-out;
        animation-fill-mode: forwards;
      `;
}};
`;
export {
  Bar,
  BarIndicator,
  Container,
  StyledTruncatedTooltipText
};
//# sourceMappingURL=styled.js.map
